@@ -1,9 +1,10 @@
-// Copyright (c) 2021 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
+// Copyright (c) 2022 TOYOTA MOTOR CORPORATION. Licensed under MIT OR Apache-2.0.
 
 use crate::{
     error::Result,
-    stream_engine::autonomous_executor::{
-        row::value::sql_value::nn_sql_value::NnSqlValue, Timestamp,
+    stream_engine::{
+        autonomous_executor::row::value::sql_value::nn_sql_value::NnSqlValue,
+        time::timestamp::Timestamp,
     },
 };
 
